<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Emër_Programi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Mbylle aplikacionin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Shfaq ndihmë </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Mbrapsht</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Pasuesi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>Mbi këtë aplikacion</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>Mbi…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>View Log</source>
        <translation>Shihni Regjistër</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="259"/>
        <location filename="../mainwindow.cpp" line="490"/>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Select ISO</source>
        <translation>Përzgjidhni ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Përzgjidhni Pajisjen USB të Synuar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Përzgjidhni kartelë ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Advanced Options</source>
        <translation>Mundësi të Mëtejshme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Krijoje sistemin ext4 të kartelave, edhe nëse ka të tillë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Ruaje drejtorinë origjinale të nisjes, kur përditësohet një “live-usb”</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Përdor pjesëtim gpt, në vend se msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>GPT partitioning</source>
        <translation>Pjesëtim GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Përditësoje (përditëso vetëm një “live-usb” ekzistues)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Mos zëvendëso kartela syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Keep syslinux files</source>
        <translation>Mbaji kartelat syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>Ignore USB/removable check</source>
        <translation>Shpërfill kontroll USB-je/të heqshmi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Temporarily disable automounting</source>
        <translation>Çaktivizoje përkohësisht vetëmontimin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Ujdise parametrin pmbr_boot për disk (s’do të bëjë nisje përmes UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Mos përdor fuseiso për të montuar kartela iso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Madhësi pjese ESP (UEFI):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Verbosity (less to more):</source>
        <translation>Hollësi (nga pak në shumë):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Make separate data partition (percent)</source>
        <translation>Krijo pjesë më vete për të dhënat (përqindje)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Format</source>
        <translation>Formatoje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Refresh drive list</source>
        <translation>Rifresko listë disqesh</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Show advanced options</source>
        <translation>Shfaq mundësi të mëtejshme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="567"/>
        <source>Mode</source>
        <translation>Mënyrë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="582"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Mënyra me tërë veçoritë - Li&amp;veUSB i shkrueshëm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Vetëm-për-lexim, s’mund të përdoret për vazhdueshmëri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="595"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>&amp;Mënyra pamje- LiveUSB vetëm për lexim (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Për shpërndarje të tjera nga antiX/MX, përdorni mënyrën pamje (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <source>Options</source>
        <translation>Mundësi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>Percent of USB-device to use:</source>
        <translation>Përqindje e pajisjes USB për t’u përdorur:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="702"/>
        <source>Label ext partition:</source>
        <translation>I vini etiketë pjesës ext:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Mos xhironi urdhra që prekin pajisjen USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Dry run (no change to system)</source>
        <translation>&lt;em&gt;Dry run&lt;/em&gt; (pa ndryshime në sistem)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>klononi prej një live-usb të montuar, ose prej një karteleje ISO.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Clone an existing live system</source>
        <translation>Klononi një sistem “Live” ekzistues</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Ujdisni nisje që nga një pjesë e fshehtëzuar, do të kërkojë për frazëkalim gjatë nisjes së parë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Encrypt</source>
        <translation>Fshehtëzoje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="780"/>
        <source>Clone running live system</source>
        <translation>Klononi sistemin “live” që po xhiron</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="76"/>
        <source>Confirmation</source>
        <translation>Ripohim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="77"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation>Pajisja %1 e synuar është më e madhe se %2 GB. Doni të vazhdohet?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="306"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Failure</source>
        <translation>Dështim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Burimi dhe vendmbërritja gjenden në të njëjtën pajisje, ju lutemi, ripërzgjidhni.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Po shkruhet %1 duke përdorur urdhrin “dd” te /dev/%2,

Ju lutemi, pritni deri sa të plotësohet procesi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>Success</source>
        <translation>Sukses</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>LiveUSB creation successful!</source>
        <translation>Krijim i suksesshëm LiveUSB-je!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>U has një gabim gjatë procesit të krijimit të LiveUSB-së</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Please select a USB device to write to</source>
        <translation>Ju lutemi, përzgjidhni një pajisje USB ku të shkruhet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Këto veprime do të asgjësojnë krejt të dhënat te 

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Do you wish to continue?</source>
        <translation>Doni të vazhdohet?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>clone</source>
        <translation>klonoje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>About %1</source>
        <translation>Mbi %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program për krjimin e një “live-usb” prej një kartele ISO, një tjetri “live-usb”, pre një live-cd/dvd, ose një sistem “live” që është duke xhiruar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Të drejta kopjimi (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>%1 License</source>
        <translation>Licencë %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>%1 Help</source>
        <translation>Ndihmë për %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Përzgjidhni një kartelë ISO për ta shkruar te pajisja USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>Kartela ISO (*.iso);;Krejt Kartelat (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>Select Source Directory</source>
        <translation>Përzgjidhni Drejtori Burim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>S’u gjet dot kartelë %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>Hide advanced options</source>
        <translation>Fshihi mundësitë e mëtejshme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="485"/>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Select Source</source>
        <translation>Përzgjidhni Burim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>Select ISO file</source>
        <translation>Përzgjidhni kartelë ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <source>Could not find a log file at: </source>
        <translation>S’u gjet dot një kartelë regjistër te: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Licencë</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Regjistër ndryshimesh</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Mbylle</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program për krjimin e një “live-usb” prej një kartele ISO, një tjetri “live-usb”, pre një live-cd/dvd, ose një sistem “live” që është duke xhiruar.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>filename</source>
        <translation>emër kartele</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Name of .iso file to open</source>
        <translation>Emër i kartelës .iso për hapje</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>[filename]</source>
        <translation>[emër kartele]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Duket të jeni futur si rrënjë, ju lutemi, që të përdorni këtë program, dilni nga llogaria dhe hyni si përdorues i zakonshëm.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>version:</source>
        <translation>version:</translation>
    </message>
</context>
</TS>